pub struct TypeId(pub u32);Expand description
Opaque integer identifier for any ontology type (entity, relation, or property).
IDs are assigned at compile time by the ontology compiler and are stable for the lifetime of a loaded ontology.
Tuple Fields
0: u32Trait Implementations
impl Copy for TypeId
Sourceimpl<'de> Deserialize<'de> for TypeId
impl<'de> Deserialize<'de> for TypeId
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TypeId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TypeId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TypeId
Sourceimpl Serialize for TypeId
impl Serialize for TypeId
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for TypeId